==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/pgassignment.php <==
<?PHP // $Id: pgassignment.php,v 1.8 2003/11/27 19:19:10 paca70 Exp $ 
      // pgassignment.php - created with Moodle 1.0.9 development (2003050400)


$string['absent'] = "Puuttuva";
$string['acceptance'] = "Hyvksyminen";
$string['acceptassessment'] = "Oletko tyytyvinen thn arviointiin?";
$string['acceptedgrades'] = "Hyvksytyt arviot(\$a)";
$string['addamendassessmentelements'] = "Lis/Muuta arviointi elementtej";
$string['afterdeadline'] = "\$a mrajan jlkeen";
$string['allgradeshaveamaximumof'] = "Kaikkien arvosanojen maksimi arvo on: \$a";
$string['allocatedon'] = "Varattuna";
$string['allocatesubmissions'] = "Jaa palautetut tehtvt arvioitaviksi";
$string['allocationsincludegoodandbad'] = "Opiskelijoille jaetut tyt pitvt sislln vhintn yhden huonon ja yhden hyvn tehtvn.";
$string['allowsubmissions'] = "Salli opiskelijoiden lhetykset";
$string['allthecommentsfor'] = "Kaikki kommentit";
$string['amendassessmentelements'] = "Muokkaa arviointi elementtej";
$string['anonymous'] = "Suorita vertaisarviointi anonyymisti";
$string['assignmentawaitinggrading'] = "Tehtv odottaa arviointia (Mraika on \$a)";
$string['assignmenthasbeengraded'] = "Tehtv on arvioitu";
$string['assignmentsgivento'] = "\$a :lle arvioitavaksi annetut tehtvt";
$string['averagegrade'] = "Arviointien keskiarvo on \$a";
$string['awaitingregrading'] = "Odottaa uudeleenarviointia (on iteration \$a)";
$string['beforedeadline'] = "\$a ennen mraikaa";
$string['biasgrade'] = "Arvioiden poikkeama";
$string['breakdownoffinalgrade'] = "Lopullisten arvioiden erittely";
$string['calculatefinalgrades'] = "Laske lopulliset arvioinnit";
$string['calculationofthefinalgrade'] = "Lopulliset lasketut avioinnit";
$string['checkallocation'] = "Tarkistetaan lhetysten allokointi...";
$string['commentsby'] = "\$a :n kommentit";
$string['completedon'] = "Suoritettu \$a";
$string['deadlineforgradingis'] = "Arvioinnin mraika on  \$a";
$string['deadlineforpeergradingreached'] = "Vertaisarvioinnin mraika saavutettu";
$string['deadlineforsubmissionis'] = "Palautuksen mraika on \$a";
$string['deadlineis'] = "Mraika on  \$a";
$string['displayfinalgrades'] = "Nyt lopulliset arvioinnit";
$string['displaygradefromteacher'] = "Nyt opettajan arviointi";
$string['displaygrading'] = "Nyt arvioinnit";
$string['displayoffinalgrades'] = "Nyt lopulliset arvioinnit";
$string['displayofgrades'] = "Miloin arvioinnit nytetn";
$string['doallocation'] = "Haluatko jatkaa tehtvien jakamista opiskelijoille?";
$string['dontshowgrades'] = "Nyt arvioinnit vasta kun kommentit on hyvksytty";
$string['editingassessmentelements'] = "Muokataan tehtv elementtej";
$string['element'] = "Arviointi elementti";
$string['elements'] = "Elementit";
$string['elementweight'] = "Elementin paino";
$string['feedbackgoeshere'] = "Palaute tulee thn";
$string['finalgrade'] = "Lopullinen arviointi";
$string['first'] = "Ensimminen";
$string['generalcomment'] = "Yleinen kommentti";
$string['gradecomments'] = "Arviointi kommentit";
$string['graded'] = "Muiden opiskelijoiden arvioinnit ja palautteet";
$string['gradedawaitingacceptance'] = "Arvioitu, odottaa hyvksynt (on iteration \$a)";
$string['gradedawaitingreply'] = "Arvioitu, odottaa vastausta (\$a)";
$string['gradedawaitingreplydeadline'] = "Arvioitu, odottaa vastausta (Mraika on \$a)";
$string['gradedby'] = "Arvoitsija \$a";
$string['gradeddate'] = "Arvionti suoritettava ennen";
$string['gradedon'] = "Arvioitu \$a";
$string['grades'] = "Arvioinnit";
$string['gradethissubmission'] = "Arvioi tm palautus";
$string['gradethiswork'] = "Arvioi tm ty";
$string['grading'] = "Arviointi";
$string['gradingaccepted'] = "Arviointi hyvksytty  \$a interations jlkeen";
$string['gradingacceptedon'] = "Arviointi hyvksytty";
$string['gradingby'] = "Arvioija \$a";
$string['gradingdetails'] = "Arvioinnin yksityiskohdat";
$string['gradinggiventothissubmission'] = "Tlle tehtvlle annettu arvioiti";
$string['gradingperformance'] = "Arvioinnin tehokkuus";
$string['gradingrepliedtoon'] = "Arviointiin vastattu";
$string['gradingsdone'] = "Arviointi suoritettu [Vertais keskiarvo]";
$string['includeself'] = "Opiskelija orvioi mys oman tyns";
$string['includeteachersgrade'] = "Sisllyt opettajan arvio vertaisarviointiin";
$string['last'] = "Viimeinen";
$string['makefinalgradesavailable'] = "Lopulliset arvioinnit ovat saatavilla";
$string['makefinalgradesunavailable'] = "Lopulliset arvioinnit evt ole saatavilla";
$string['managingpeerassignment'] = "Vertaisarvioidun tehtvn hallinta";
$string['modulename'] = "Vertaisarvioitu tehtv";
$string['modulenameplural'] = "Vertaisarvioidut tehtvt";
$string['newsubmission'] = "Uusi palautus";
$string['next'] = "Seuraava";
$string['noactiontakeninwrongphase'] = "Ei toimi";
$string['nopeergrades'] = "Ei vartaiarviointeja tlle palautukselle";
$string['nosubmissionfrom'] = "\$a ei palautusta";
$string['nosubmissions'] = "Palutuksia ei ole vastaanotettu";
$string['nosubmissionsgraded'] = "Tll hetkell ei ole arvioituja tai uudeleen arvioituja palautuksia. ";
$string['nosubmissionstograde'] = "Tll hetkell ei palautuksia arvioitavaksi";
$string['nosubmissionstoremove'] = "Ei palautuksia poistettavaksi";
$string['notavailable'] = "Tt tehtv valmistellaan, se ei ole viel saatavilla.";
$string['notenoughmarked'] = "Valittuja tehvvi ei ole riittvsti jotta  jaetut tyt pitisivt sislln vhintn yhden huonon ja yhden hyvn tehtvn.";
$string['noteonassessmentelements'] = "huomaa ett vertaisarvioisun tehvn arvioiti on jaettu useisiin 'Arviointi elementteihin'.<BR>
	Tm tekee arvioinnista helmpompaa ja yhdenmukaisempaa. Opettaja sinun pit list nm 'Arviointi Elementit' ennen tehtvn antamista opiskejoille.
	Tm tehdn klikaamalla listty vertaiarvioitua tehtv ja valitsemalla ensimminen vaihtoehto &quot;Vartaisarvioidun tehtvn hallinta&quot valikosta.";
$string['notgraded'] = "Ei arviointia, vain muiden opiskelijoiden palaute";
$string['notyetassessedby'] = "\$a ei ole viel katsonut";
$string['notyetgraded'] = "Arvioimatta";
$string['notyetsubmitted'] = "Palauttamatta";
$string['noworksubmittedforotherstograde'] = "Tehtv ei palautettu toisten arvioitavaksi";
$string['numbermarked'] = "Opettajan  arvioimien tehtvien mr: \$a";
$string['numberofallocations'] = "Opiskelijan arvioimien tehtvien mr: \$a";
$string['numberofallocationsreduced'] = "Opiskelijoiden tehtv mr on vhenetty: \$a";
$string['numberofassessmentelements'] = "Arviointielementtien mr";
$string['numberofassessors'] = "Vertaisarvioitsijoidem mr per ty";
$string['numberofpeerallocationstoolow'] = "Vertaisarvioitsijoiden mrn pitsi olla 4 tai enemmn jotta voitaiin kytt high/low submissions";
$string['numberofstudents'] = "Tlle kurssille liittyneiden opiskelijoiden mr: \$a";
$string['numberofsubmissions'] = "Palutettettuja tehtvi: \$a";
$string['overallpeergrade'] = "Yleisin vertaisarvoiti: \$a";
$string['peerassessmentsalreadydisabled'] = "Vertaisarvioiti on jo estetty";
$string['peerassessmentsdisabled'] = "Vertaisarvointi estetty";
$string['peergrade'] = "Vertaisarviointi";
$string['peergrades'] = "Vertaisarvioinnit";
$string['phase'] = "Vaihe";
$string['present'] = "On";
$string['previous'] = "Edellinen";
$string['qualityofcomments'] = "Kommenttien laatu";
$string['regradethissubmission'] = "Uudelllenarvioi tm tehtv";
$string['reliabilitygrade'] = "Arvioinnin luotettavuus";
$string['removeallocationsquestion'] = "Oletko varma ett haluat poistaa opiskelijoille annetut tehtvt?";
$string['removepeersubmissions'] = "Poista arvoitavat tehtvt opiskelijoilta";
$string['reply'] = "Vastaa";
$string['returntopeergrading'] = "Palaa vertaisarviointiin";
$string['returntosubmissionpage'] = "Palaa lhetyssivulle";
$string['savecommentgrades'] = "Tallenna kommenttien arvioinnit";
$string['savemyassessment'] = "Tallenna arviointini";
$string['savemyreply'] = "Tallenna vastaukseni";
$string['scale10'] = "Pistett 10:st";
$string['scale100'] = "Pistett 100:sta";
$string['scale20'] = "Pistett 20:st";
$string['scalecorrect'] = "2 pisteen Oikein/Vrin asteikko";
$string['scaleexcellent4'] = "4 pisteen Kiitettv/Heikko asteikko";
$string['scaleexcellent5'] = "5 pisteen Kiitettv/Heikko asteikko";
$string['scaleexcellent7'] = "7 pisteen Kiitettv/Heikko asteikko";
$string['scalegood3'] = "3 pisteen Kiitettv/Heikko asteikko";
$string['scalepresent'] = "2 pisteen On/Puuttuu asteikko";
$string['scaleyes'] = "2 pisteen Kyll/Ei asteikko";
$string['selfassessmentgivento'] = "Itsearviointi annettu \$a :lle";
$string['showfeedback'] = "Nyt palaute";
$string['showgrades'] = "Nyt arvioinnit komettien kanssa";
$string['showgrading'] = "Nyt arviointi";
$string['showstatus'] = "Nyt vertaisarvioinnin tilanne";
$string['skipback'] = "Siirry edelliseen";
$string['skipforward'] = "Siirry seuravaan";
$string['specimengradingform'] = "Esimerkki arviointilomake";
$string['stopsubmissions'] = "Est palauttaminen";
$string['submissiondate'] = "Tehtvien palautus ennen";
$string['submissionfrom'] = "Palautus #\$a ";
$string['submissions'] = "Palautukset";
$string['submissionsalreadyallowed'] = "Palauttaminen on jo sallittu";
$string['submissionsalreadystopped'] = "Palauttaminen on jo estetty";
$string['submissionsawaitinggrading'] = "Arviointia odottavat tehtvt (\$a)";
$string['submissionsawaitingregrading'] = "Uudelleen arviointia odottvat tehtvt (\$a)";
$string['submittedby'] = "Palauttaja \$a";
$string['teacherscomments'] = "Opettajan kommentit";
$string['teachersgrade'] = "Opettajan arviointi";
$string['teachersgradeis'] = "Opettajan arviointi on ";
$string['teachersgrades'] = "Opettajien arviointi";
$string['thecurrentgradeis'] = "Tmn hetkinen arviointi on";
$string['thegradegiventothissubmissionis'] = "Tlle tylle annettu arviointi on";
$string['thegradeis'] = "Arviointi on";
$string['therearegradedpeersubmissions'] = "\$a arvioitua tyt jaettu opiskelijoille";
$string['therearepeersubmissions'] = "\$a tyt jaettu opiskelijoille";
$string['typeofscale'] = "Asteikon tyyppi";
$string['warningonamendingelements'] = "VAROITUS: Jrjestelmss on jo suoritettu arviointeja. <BR>L muuta elementtien lukumr, arvointi tapaa tai elementtien painotuksia.";
$string['weightingofgrading'] = "Arviointi tehokkuuden painotus";
$string['weightingofpeer'] = "Vertaisarvioinnin painotus";
$string['weightingofteacher'] = "Opettajan arvioinnin painotus";
$string['workofotherstudentsbeinggraded'] = "Arvioitavanasi on seuraavat tyt";
$string['youhavenotbeenallocatedanyworktograde'] = "Sinulle ei ole annettu yhtn arvoitavaa tyt";
$string['yourworkbeinggraded'] = "Oman tysi arvioinnit  \$a ";

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fi/pgassignment.php <==
<?PHP // $Id$ 
      // pgassignment.php - created with Moodle 1.0.9 development (2003050400)


$string['absent'] = "Puuttuva";
$string['acceptance'] = "Hyvksyminen";
$string['acceptassessment'] = "Oletko tyytyvinen thn arviointiin?";
$string['acceptedgrades'] = "Hyvksytyt arviot(\$a)";
$string['addamendassessmentelements'] = "Lis/Muuta arviointi elementtej";
$string['afterdeadline'] = "\$a mrajan jlkeen";
$string['allgradeshaveamaximumof'] = "Kaikkien arvosanojen maksimi arvo on: \$a";
$string['allocatedon'] = "Varattuna";
$string['allocatesubmissions'] = "Jaa palautetut tehtvt arvioitaviksi";
$string['allocationsincludegoodandbad'] = "Opiskelijoille jaetut tyt pitvt sislln vhintn yhden huonon ja yhden hyvn tehtvn.";
$string['allowsubmissions'] = "Salli opiskelijoiden lhetykset";
$string['allthecommentsfor'] = "Kaikki kommentit";
$string['amendassessmentelements'] = "Muokkaa arviointi elementtej";
$string['anonymous'] = "Suorita vertaisarviointi anonyymisti";
$string['assignmentawaitinggrading'] = "Tehtv odottaa arviointia (Mraika on \$a)";
$string['assignmenthasbeengraded'] = "Tehtv on arvioitu";
$string['assignmentsgivento'] = "\$a :lle arvioitavaksi annetut tehtvt";
$string['averagegrade'] = "Arviointien keskiarvo on \$a";
$string['awaitingregrading'] = "Odottaa uudeleenarviointia (on iteration \$a)";
$string['beforedeadline'] = "\$a ennen mraikaa";
$string['biasgrade'] = "Arvioiden poikkeama";
$string['breakdownoffinalgrade'] = "Lopullisten arvioiden erittely";
$string['calculatefinalgrades'] = "Laske lopulliset arvioinnit";
$string['calculationofthefinalgrade'] = "Lopulliset lasketut avioinnit";
$string['checkallocation'] = "Tarkistetaan lhetysten allokointi...";
$string['commentsby'] = "\$a :n kommentit";
$string['completedon'] = "Suoritettu \$a";
$string['deadlineforgradingis'] = "Arvioinnin mraika on  \$a";
$string['deadlineforpeergradingreached'] = "Vertaisarvioinnin mraika saavutettu";
$string['deadlineforsubmissionis'] = "Palautuksen mraika on \$a";
$string['deadlineis'] = "Mraika on  \$a";
$string['displayfinalgrades'] = "Nyt lopulliset arvioinnit";
$string['displaygradefromteacher'] = "Nyt opettajan arviointi";
$string['displaygrading'] = "Nyt arvioinnit";
$string['displayoffinalgrades'] = "Nyt lopulliset arvioinnit";
$string['displayofgrades'] = "Miloin arvioinnit nytetn";
$string['doallocation'] = "Haluatko jatkaa tehtvien jakamista opiskelijoille?";
$string['dontshowgrades'] = "Nyt arvioinnit vasta kun kommentit on hyvksytty";
$string['editingassessmentelements'] = "Muokataan tehtv elementtej";
$string['element'] = "Arviointi elementti";
$string['elements'] = "Elementit";
$string['elementweight'] = "Elementin paino";
$string['feedbackgoeshere'] = "Palaute tulee thn";
$string['finalgrade'] = "Lopullinen arviointi";
$string['first'] = "Ensimminen";
$string['generalcomment'] = "Yleinen kommentti";
$string['gradecomments'] = "Arviointi kommentit";
$string['graded'] = "Muiden opiskelijoiden arvioinnit ja palautteet";
$string['gradedawaitingacceptance'] = "Arvioitu, odottaa hyvksynt (on iteration \$a)";
$string['gradedawaitingreply'] = "Arvioitu, odottaa vastausta (\$a)";
$string['gradedawaitingreplydeadline'] = "Arvioitu, odottaa vastausta (Mraika on \$a)";
$string['gradedby'] = "Arvoitsija \$a";
$string['gradeddate'] = "Arvionti suoritettava ennen";
$string['gradedon'] = "Arvioitu \$a";
$string['grades'] = "Arvioinnit";
$string['gradethissubmission'] = "Arvioi tm palautus";
$string['gradethiswork'] = "Arvioi tm ty";
$string['grading'] = "Arviointi";
$string['gradingaccepted'] = "Arviointi hyvksytty  \$a interations jlkeen";
$string['gradingacceptedon'] = "Arviointi hyvksytty";
$string['gradingby'] = "Arvioija \$a";
$string['gradingdetails'] = "Arvioinnin yksityiskohdat";
$string['gradinggiventothissubmission'] = "Tlle tehtvlle annettu arvioiti";
$string['gradingperformance'] = "Arvioinnin tehokkuus";
$string['gradingrepliedtoon'] = "Arviointiin vastattu";
$string['gradingsdone'] = "Arviointi suoritettu [Vertais keskiarvo]";
$string['includeself'] = "Opiskelija orvioi mys oman tyns";
$string['includeteachersgrade'] = "Sisllyt opettajan arvio vertaisarviointiin";
$string['last'] = "Viimeinen";
$string['makefinalgradesavailable'] = "Lopulliset arvioinnit ovat saatavilla";
$string['makefinalgradesunavailable'] = "Lopulliset arvioinnit evt ole saatavilla";
$string['managingpeerassignment'] = "Vertaisarvioidun tehtvn hallinta";
$string['modulename'] = "Vertaisarvioitu tehtv";
$string['modulenameplural'] = "Vertaisarvioidut tehtvt";
$string['newsubmission'] = "Uusi palautus";
$string['next'] = "Seuraava";
$string['noactiontakeninwrongphase'] = "Ei toimi";
$string['nopeergrades'] = "Ei vartaiarviointeja tlle palautukselle";
$string['nosubmissionfrom'] = "\$a ei palautusta";
$string['nosubmissions'] = "Palutuksia ei ole vastaanotettu";
$string['nosubmissionsgraded'] = "Tll hetkell ei ole arvioituja tai uudeleen arvioituja palautuksia. ";
$string['nosubmissionstograde'] = "Tll hetkell ei palautuksia arvioitavaksi";
$string['nosubmissionstoremove'] = "Ei palautuksia poistettavaksi";
$string['notavailable'] = "Tt tehtv valmistellaan, se ei ole viel saatavilla.";
$string['notenoughmarked'] = "Valittuja tehvvi ei ole riittvsti jotta  jaetut tyt pitisivt sislln vhintn yhden huonon ja yhden hyvn tehtvn.";
$string['noteonassessmentelements'] = "huomaa ett vertaisarvioisun tehvn arvioiti on jaettu useisiin 'Arviointi elementteihin'.<br />
	Tm tekee arvioinnista helmpompaa ja yhdenmukaisempaa. Opettaja sinun pit list nm 'Arviointi Elementit' ennen tehtvn antamista opiskejoille.
	Tm tehdn klikaamalla listty vertaiarvioitua tehtv ja valitsemalla ensimminen vaihtoehto &quot;Vartaisarvioidun tehtvn hallinta&quot valikosta.";
$string['notgraded'] = "Ei arviointia, vain muiden opiskelijoiden palaute";
$string['notyetassessedby'] = "\$a ei ole viel katsonut";
$string['notyetgraded'] = "Arvioimatta";
$string['notyetsubmitted'] = "Palauttamatta";
$string['noworksubmittedforotherstograde'] = "Tehtv ei palautettu toisten arvioitavaksi";
$string['numbermarked'] = "Opettajan  arvioimien tehtvien mr: \$a";
$string['numberofallocations'] = "Opiskelijan arvioimien tehtvien mr: \$a";
$string['numberofallocationsreduced'] = "Opiskelijoiden tehtv mr on vhenetty: \$a";
$string['numberofassessmentelements'] = "Arviointielementtien mr";
$string['numberofassessors'] = "Vertaisarvioitsijoidem mr per ty";
$string['numberofpeerallocationstoolow'] = "Vertaisarvioitsijoiden mrn pitsi olla 4 tai enemmn jotta voitaiin kytt high/low submissions";
$string['numberofstudents'] = "Tlle kurssille liittyneiden opiskelijoiden mr: \$a";
$string['numberofsubmissions'] = "Palutettettuja tehtvi: \$a";
$string['overallpeergrade'] = "Yleisin vertaisarvoiti: \$a";
$string['peerassessmentsalreadydisabled'] = "Vertaisarvioiti on jo estetty";
$string['peerassessmentsdisabled'] = "Vertaisarvointi estetty";
$string['peergrade'] = "Vertaisarviointi";
$string['peergrades'] = "Vertaisarvioinnit";
$string['phase'] = "Vaihe";
$string['present'] = "On";
$string['previous'] = "Edellinen";
$string['qualityofcomments'] = "Kommenttien laatu";
$string['regradethissubmission'] = "Uudelllenarvioi tm tehtv";
$string['reliabilitygrade'] = "Arvioinnin luotettavuus";
$string['removeallocationsquestion'] = "Oletko varma ett haluat poistaa opiskelijoille annetut tehtvt?";
$string['removepeersubmissions'] = "Poista arvoitavat tehtvt opiskelijoilta";
$string['reply'] = "Vastaa";
$string['returntopeergrading'] = "Palaa vertaisarviointiin";
$string['returntosubmissionpage'] = "Palaa lhetyssivulle";
$string['savecommentgrades'] = "Tallenna kommenttien arvioinnit";
$string['savemyassessment'] = "Tallenna arviointini";
$string['savemyreply'] = "Tallenna vastaukseni";
$string['scale10'] = "Pistett 10:st";
$string['scale100'] = "Pistett 100:sta";
$string['scale20'] = "Pistett 20:st";
$string['scalecorrect'] = "2 pisteen Oikein/Vrin asteikko";
$string['scaleexcellent4'] = "4 pisteen Kiitettv/Heikko asteikko";
$string['scaleexcellent5'] = "5 pisteen Kiitettv/Heikko asteikko";
$string['scaleexcellent7'] = "7 pisteen Kiitettv/Heikko asteikko";
$string['scalegood3'] = "3 pisteen Kiitettv/Heikko asteikko";
$string['scalepresent'] = "2 pisteen On/Puuttuu asteikko";
$string['scaleyes'] = "2 pisteen Kyll/Ei asteikko";
$string['selfassessmentgivento'] = "Itsearviointi annettu \$a :lle";
$string['showfeedback'] = "Nyt palaute";
$string['showgrades'] = "Nyt arvioinnit komettien kanssa";
$string['showgrading'] = "Nyt arviointi";
$string['showstatus'] = "Nyt vertaisarvioinnin tilanne";
$string['skipback'] = "Siirry edelliseen";
$string['skipforward'] = "Siirry seuravaan";
$string['specimengradingform'] = "Esimerkki arviointilomake";
$string['stopsubmissions'] = "Est palauttaminen";
$string['submissiondate'] = "Tehtvien palautus ennen";
$string['submissionfrom'] = "Palautus #\$a ";
$string['submissions'] = "Palautukset";
$string['submissionsalreadyallowed'] = "Palauttaminen on jo sallittu";
$string['submissionsalreadystopped'] = "Palauttaminen on jo estetty";
$string['submissionsawaitinggrading'] = "Arviointia odottavat tehtvt (\$a)";
$string['submissionsawaitingregrading'] = "Uudelleen arviointia odottvat tehtvt (\$a)";
$string['submittedby'] = "Palauttaja \$a";
$string['teacherscomments'] = "Opettajan kommentit";
$string['teachersgrade'] = "Opettajan arviointi";
$string['teachersgradeis'] = "Opettajan arviointi on ";
$string['teachersgrades'] = "Opettajien arviointi";
$string['thecurrentgradeis'] = "Tmn hetkinen arviointi on";
$string['thegradegiventothissubmissionis'] = "Tlle tylle annettu arviointi on";
$string['thegradeis'] = "Arviointi on";
$string['therearegradedpeersubmissions'] = "\$a arvioitua tyt jaettu opiskelijoille";
$string['therearepeersubmissions'] = "\$a tyt jaettu opiskelijoille";
$string['typeofscale'] = "Asteikon tyyppi";
$string['warningonamendingelements'] = "VAROITUS: Jrjestelmss on jo suoritettu arviointeja. <br />L muuta elementtien lukumr, arvointi tapaa tai elementtien painotuksia.";
$string['weightingofgrading'] = "Arviointi tehokkuuden painotus";
$string['weightingofpeer'] = "Vertaisarvioinnin painotus";
$string['weightingofteacher'] = "Opettajan arvioinnin painotus";
$string['workofotherstudentsbeinggraded'] = "Arvioitavanasi on seuraavat tyt";
$string['youhavenotbeenallocatedanyworktograde'] = "Sinulle ei ole annettu yhtn arvoitavaa tyt";
$string['yourworkbeinggraded'] = "Oman tysi arvioinnit  \$a ";

?>
